@@ -207,13 +207,13 @@ class VerifyToken:
         else:
             is_all_data = False  # 安全考虑，含False都为False
         # 结束合并角色权限
-        if self.proxy_none_response:
-            if ([0] == permission_list) or (not permission_list):
-                handle_abnormal(
-                    message='无 "{0}-{1}" 的访问权限({2})'.format(
-                        center_name, permission_name, str(permission_list)),
-                    status=403,
-                )
+        # if self.proxy_none_response:
+        #     if ([0] == permission_list) or (not permission_list):
+        #         handle_abnormal(
+        #             message='无 "{0}-{1}" 的访问权限({2})'.format(
+        #                 center_name, permission_name, str(permission_list)),
+        #             status=403,
+        #         )
         permission_status = {
             'permission_list': permission_list, 'is_all_data': is_all_data}
         return permission_status
